searchData={"items":[{"type":"module","title":"Broadcast","doc":"Broadcast to multiple social media domains simultaneously through a unified interface.","ref":"Broadcast.html"},{"type":"function","title":"Broadcast.post_all/1","doc":"Posts a given status message to both Mastodon and Bluesky platforms.","ref":"Broadcast.html#post_all/1"},{"type":"function","title":"Parameters - Broadcast.post_all/1","doc":"The function takes a map containing the necessary parameters for posting:\n\n  * `:status` - a string representing the status message to be posted.\n  * `:mastodon_access_token` - the access token for the Mastodon account for authentication.\n  * `:bluesky_handle` - the handle (username) of the Bluesky account to post the status.\n  * `:bluesky_password` - the password for the Bluesky account for authentication.","ref":"Broadcast.html#post_all/1-parameters"},{"type":"function","title":"Examples - Broadcast.post_all/1","doc":"iex> post_all(%{\n  ...>   status: \"Hello World!\",\n  ...>   mastodon_access_token: \"your_mastodon_token\",\n  ...>   bluesky_handle: \"your_bluesky_handle\",\n  ...>   bluesky_password: \"your_bluesky_password\"\n  ...> })\n  {:ok, [mastodon_result, bluesky_result]}","ref":"Broadcast.html#post_all/1-examples"},{"type":"function","title":"Broadcast.post_bluesky_status/3","doc":"Posts a status update to the Bluesky social network.","ref":"Broadcast.html#post_bluesky_status/3"},{"type":"function","title":"Parameters - Broadcast.post_bluesky_status/3","doc":"* `handle`: a string representing the user identifier on the Bluesky platform.\n  * `password`: a string containing the user password for authentication.\n  * `status`: a string representing the status update to be posted.","ref":"Broadcast.html#post_bluesky_status/3-parameters"},{"type":"function","title":"Examples - Broadcast.post_bluesky_status/3","doc":"iex> post_bluesky_status(\"your_user_handle\", \"your_password\", \"Hello, Mastodon!\")\n  {:ok, response}","ref":"Broadcast.html#post_bluesky_status/3-examples"},{"type":"function","title":"Broadcast.post_mastodon_status/2","doc":"Posts a status update to the Mastodon social media platform.","ref":"Broadcast.html#post_mastodon_status/2"},{"type":"function","title":"Parameters - Broadcast.post_mastodon_status/2","doc":"* `access_token` - The bearer token used for authentication with the Mastodon API.\n  * `status` - The string representing the status update to be posted.","ref":"Broadcast.html#post_mastodon_status/2-parameters"},{"type":"function","title":"Examples - Broadcast.post_mastodon_status/2","doc":"iex> post_mastodon_status(\"your_access_token\", \"Hello, Mastodon!\")\n  {:ok, response}","ref":"Broadcast.html#post_mastodon_status/2-examples"},{"type":"extras","title":"Broadcast","doc":"# Broadcast\n\nBroadcast is an Elixir library for posting to social media websites, currently with support for Bluesky and Mastodon.","ref":"readme.html"},{"type":"extras","title":"Installation - Broadcast","doc":"Add `broadcast` to your list of dependancies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:broadcast, \"~> 0.1.0\"}\n  ]\nend\n```\n\nThen run `mix deps.get` to install dependencies. Broadcast requires Elixir 1.17 or later.","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Broadcast","doc":"Post to Bluesky and Mastodon simultaneously, with `post_all/1`:\n\n```elixir\n{:ok, results} = Broadcast.post_all(\n  %{\n    status: \"Hello, world!\",\n    mastodon_access_token: \"your_mastodon_access_token\",\n    bluesky_handle: \"your_bluesky_handle\",\n    bluesky_password: \"your_bluesky_password\"\n  }\n)\n```\n\nPost to Mastodon, with `post_mastodon_status/2`:\n\n```elixir\n{:ok, results} = Broadcast.post_mastodon_status(\n  \"mastodon_access_token\",\n  \"Hello world!\"\n)\n```\n\nPost to Bluesky, with `post_bluesky_status/3`:\n\n```elixir\n{:ok, result} = Broadcast.post_bluesky_status(\n  \"your_bluesky_handle\",\n  \"your_bluesky_password\",\n  \"Hello world!\"\n)\n```","ref":"readme.html#usage"},{"type":"extras","title":"License - Broadcast","doc":"Broadcast's source code is released under the [MIT License](https://github.com/skyefreeman/broadcast.ex/blob/main/LICENSE).","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}